@@ -174,7 +174,8 @@ class OpenADRClient:
                    reading_type=enums.READING_TYPE.DIRECT_READ,
                    report_type=enums.REPORT_TYPE.READING, sampling_rate=None, data_source=None,
                    scale="none", unit=None, power_ac=True, power_hertz=50, power_voltage=230,
-                   market_context=None, end_device_asset_mrid=None, report_data_source=None):
+                   market_context=None, end_device_asset_mrid=None, report_data_source=None,
+                   on_change=False):
         """
         Add a new reporting capability to the client.
 
@@ -212,6 +213,10 @@ class OpenADRClient:
         :param str market_context: The Market Context that this report belongs to.
         :param str end_device_asset_mrid: the Meter ID for the end device that is measured by this report.
         :param report_data_source: A (list of) target(s) that this report is related to.
+        :param boolean on_change: Whether this measurement supports reporting when the value changes.
+                                  To use this functionality, call the ``client.report_on_change`` method
+                                  with parameters ``report_id, r_id, value``. You get the ``report_id``
+                                  and the ``r_id`` from the return of the ``client.add_report`` call.
         """
 
         # Verify input
@@ -234,11 +239,11 @@ class OpenADRClient:
         if sampling_rate is None:
             sampling_rate = objects.SamplingRate(min_period=timedelta(seconds=10),
                                                  max_period=timedelta(hours=24),
-                                                 on_change=False)
+                                                 on_change=on_change)
         elif isinstance(sampling_rate, timedelta):
             sampling_rate = objects.SamplingRate(min_period=sampling_rate,
                                                  max_period=sampling_rate,
-                                                 on_change=False)
+                                                 on_change=on_change)
 
         if data_collection_mode not in ('incremental', 'full'):
             raise ValueError("The data_collection_mode should be 'incremental' or 'full'.")
@@ -407,7 +412,8 @@ class OpenADRClient:
 
     async def request_event(self, reply_limit=None):
         """
-        Request the next Event from the VTN, if it has any.
+        Requests all pending and active events from the VTN, if any.
+        Returns a response_type, response_payload tuple.
         """
         payload = {'request_id': utils.generate_id(),
                    'ven_id': self.ven_id,
@@ -547,6 +553,11 @@ class OpenADRClient:
         Create a single report in response to a request from the VTN.
         """
 
+    def update_report_on_change(self, report_id, r_id, value):
+        """
+        Creates a new report after a value changed.
+        """
+
     async def update_report(self, report_request_id):
         """
         Call the previously registered report callback and send the result as a message to the VTN.
