@@ -92,6 +92,8 @@ class VTNService:
                 # Add the request fingerprint to the message so that the handler can check for it.
                 if request.secure and message_type == 'oadrCreatePartyRegistration':
                     message_payload['fingerprint'] = utils.get_cert_fingerprint_from_request(request)
+                if message_type == 'oadrCreatePartyRegistration':
+                    message_payload['ip_address'] = request.remote
                 response_type, response_payload = await self.handle_message(message_type,
                                                                             message_payload)
             except Exception as err:
@@ -186,7 +188,7 @@ class VTNService:
                                                                   enums.STATUS_CODES.COMPLIANCE_ERROR,
                                                                   "A message of type "
                                                                   f"{message_type} should not be "
-                                                                  "sent to this endpoint")
+                                                                  f"sent to this endpoint ({self.__service_name__})")
         logger.info(f"Responding to {message_type} with a {response_type} message: {response_payload}.")
         hooks.call('after_handle', response_type, response_payload)
         return response_type, response_payload
